@@ -167,6 +167,13 @@ class SftpDownload:
         recursive: bool = config['recursive']
         to: str = config['to']
 
+        try:
+            to = render_from_entry(to, entry)
+        except RenderError as e:
+            logger.error('Could not render path: {}', to)
+            entry.fail(str(e))  # type: ignore
+            return
+
         try:
             sftp.download(path, to, recursive, delete_origin)
         except SftpError as e:
