@@ -29,7 +29,7 @@ IMMUTABLE_LISTS = ['ratings', 'checkins']
 
 Base = db_schema.versioned_base('imdb_list', 0)
 
-MOVIE_TYPES = ['documentary', 'tvmovie', 'video', 'short', 'movie']
+MOVIE_TYPES = ['documentary', 'tvmovie', 'video', 'short', 'movie', 'tvspecial']
 SERIES_TYPES = ['tvseries', 'tvepisode', 'tvminiseries']
 OTHER_TYPES = ['videogame']
 
@@ -76,11 +76,12 @@ class ImdbEntrySet(MutableSet):
                         'type': 'object',
                         'properties': {
                             'ubid-main': {'type': 'string'},
-                            'sess-at-main': {'type': 'string'},
+                            'at-main': {'type': 'string'},
                         },
+                        'required': ['ubid-main', 'at-main'],
                     },
                 ],
-                'error_oneOf': 'Please inform a dict with the cookies, a string in json format, or a path to the file',
+                'error_oneOf': 'Please use a dict with the cookies, a string in json format, or a path to the file',
             },
             'list': {'type': 'string'},
             'force_language': {'type': 'string', 'default': 'en-us'},
