@@ -5,6 +5,7 @@ import time
 from collections import defaultdict
 from copy import copy
 from datetime import datetime
+from typing import List, Union
 
 from loguru import logger
 from sqlalchemy import not_
@@ -311,7 +312,7 @@ class FilterSeriesBase:
                             'Series `{}` is configured multiple times in series plugin.', series
                         )
                     # Combine the config dicts for both instances of the show
-                    unique_series[series].update(series_settings)
+                    merge_dict_from_to(series_settings, unique_series[series])
         # Turn our all_series dict back into a list
         # sort by reverse alpha, so that in the event of 2 series with common prefix, more specific is parsed first
         return [{s: unique_series[s]} for s in sorted(unique_series, reverse=True)]
@@ -323,7 +324,7 @@ class FilterSeriesBase:
         native_series = self.prepare_config(task.config.get('series', {}))
         merging_series = self.prepare_config(config)
         task.config['series'] = self.combine_series_lists(
-            merging_series, native_series, log_once=True
+            native_series, merging_series, log_once=True
         )
         return task.config['series']
 
@@ -622,7 +623,22 @@ class FilterSeries(FilterSeriesBase):
         :param series_entries: dict mapping Episodes or Seasons to entries for that episode or season_pack
         :param config: Series configuration
         """
-        accepted_seasons = []
+        accepted_seasons: List[int] = []
+
+        def _exclude_season_on_accept(
+            *args,
+            series_entity: Union[db.Season, db.Episode],
+            accepted_seasons_list: List[int],
+            **kwargs,
+        ) -> None:
+            # need to reject all other episode/season packs for an accepted season during the task,
+            # can't wait for task learn phase
+            if series_entity.is_season:
+                logger.debug(
+                    'adding season number `{}` to accepted seasons for this task',
+                    series_entity.season,
+                )
+                accepted_seasons_list.append(series_entity.season)
 
         # sort for season packs first, order by season number ascending. Uses -1 in case entity does not return a
         # season number or sort will crash
@@ -632,6 +648,15 @@ class FilterSeries(FilterSeriesBase):
             if not entries:
                 continue
 
+            # Add season exclude hook to all entries so it will get added to list in all code paths of entry acceptance
+            for entry in entries:
+                entry.add_hook(
+                    action='accept',
+                    func=_exclude_season_on_accept,
+                    series_entity=entity,
+                    accepted_seasons_list=accepted_seasons,
+                )
+
             reason = None
 
             logger.debug('start with entities: {}', [e['title'] for e in entries])
@@ -652,7 +677,7 @@ class FilterSeries(FilterSeriesBase):
             # Determine episode threshold for season pack
             ep_threshold = season_packs['threshold'] if season_packs else 0
 
-            # check that a season ack for this season wasn't already accepted in this task run
+            # check that a season pack for this season wasn't already accepted in this task run
             if entity.season in accepted_seasons:
                 for entry in entries:
                     entry.reject(
@@ -777,14 +802,6 @@ class FilterSeries(FilterSeriesBase):
             reason = reason or 'choosing first acceptable match'
             best.accept(reason)
 
-            # need to reject all other episode/season packs for an accepted season during the task,
-            # can't wait for task learn phase
-            if entity.is_season:
-                logger.debug(
-                    'adding season number `{}` to accepted seasons for this task', entity.season
-                )
-                accepted_seasons.append(entity.season)
-
     def process_propers(self, config, episode, entries):
         """
         Accepts needed propers. Nukes episodes from which there exists proper.
