@@ -35,7 +35,7 @@ class UrlRewriteETTV:
             soup = get_soup(page.text)
         except Exception as e:
             raise UrlRewritingError(e)
-        tag_a = soup.select_one('a.download_link.magnet')
+        tag_a = soup.select_one('a[href^="magnet:"]')
         if not tag_a:
             raise UrlRewritingError(f"Unable to locate download link from url {url}")
         return tag_a.get('href')
