@@ -2,35 +2,45 @@
 
 
 import re
+from urllib.request import ProxyHandler
 
 import feedparser
-from urllib.request import ProxyHandler
 from loguru import logger
 
 from flexget import entry, plugin
+from flexget.components.sites.utils import normalize_unicode
 from flexget.entry import Entry
 from flexget.event import event
 from flexget.plugin import PluginError
+from flexget.utils import qualities
 from flexget.utils.requests import RequestException
 from flexget.utils.soup import get_soup
-from flexget.utils import qualities
-from flexget.components.sites.utils import normalize_unicode
+
 try:
-    from cloudscraper.exceptions import CloudflareException, CaptchaException
+    from cloudscraper.exceptions import CaptchaException, CloudflareException
+
     cf_exceptions = (CloudflareException, CaptchaException)
 except ModuleNotFoundError:
     cf_exceptions = ()
-    pass # cloudscraper module is optional
+    pass  # cloudscraper module is optional
 
 __authors__ = 'danfocus, Karlson2k'
 
 logger = logger.bind(name='lostfilm')
 
-RSS_TITLE_REGEXP = re.compile(r'^(?P<sr_rus>[^)(]+?)(?: \((?P<sr_org>[^)]+)\))?\. (?:(?P<ep_rus>.*)\. )?\(S(?P<season>\d+)E(?P<episode>\d+)\)$')
-RSS_LINK_REGEXP = re.compile(r'^https?://[a-z./]+/series/(?P<sr_org2>.+)/season_(?P<season>\d+)/episode_(?P<episode>\d+)/$')
+RSS_TITLE_REGEXP = re.compile(
+    r'^(?P<sr_rus>[^)(]+?)(?: \((?P<sr_org>[^)]+)\))?\. (?:(?P<ep_rus>.*)\. )?\(S(?P<season>\d+)E(?P<episode>\d+)\)$'
+)
+RSS_LINK_REGEXP = re.compile(
+    r'^https?://[a-z./]+/series/(?P<sr_org2>.+)/season_(?P<season>\d+)/episode_(?P<episode>\d+)/$'
+)
 RSS_LF_ID_REGEXP = re.compile(r'/Images/(?P<id>\d+)/Posters/image\.(?:png|jpg|jpeg)')
-PAGE_TEXT_REGEXP = re.compile(r'^\s*(?P<season>\d+)\s+сезон\s+(?P<episode>\d+)\s+серия\.(?:\s(?P<ep_rus>[^(]+?(?:\([^)]+?\))??))?(?:\s+\((?P<ep_org>[^)(]*?(?:\([^)]+?\))??)\s?\))?$')
-PAGE_LINKMAIN_REGEXP = re.compile(r'(?:(?P<sr_rus>.+?)\.\s+)??(?:(?P<season>\d+) сезон, (?P<episode>\d+) серия\.\s+)?(?:(?P<ql>[0-9A-Za-z]+)\s)?(?P<tp>\b[A-Za-z-]*(?:Rip|RIP|rip))$')
+PAGE_TEXT_REGEXP = re.compile(
+    r'^\s*(?P<season>\d+)\s+сезон\s+(?P<episode>\d+)\s+серия\.(?:\s(?P<ep_rus>[^(]+?(?:\([^)]+?\))??))?(?:\s+\((?P<ep_org>[^)(]*?(?:\([^)]+?\))??)\s?\))?$'
+)
+PAGE_LINKMAIN_REGEXP = re.compile(
+    r'(?:(?P<sr_rus>.+?)\.\s+)??(?:(?P<season>\d+) сезон, (?P<episode>\d+) серия\.\s+)?(?:(?P<ql>[0-9A-Za-z]+)\s)?(?P<tp>\b[A-Za-z-]*(?:Rip|RIP|rip))$'
+)
 
 quality_map = {
     'SD': '480p.mp3.xvid',
@@ -49,13 +59,16 @@ SITE_URLS = [
     'https://www.lostfilm.tv/',
 ]
 
-SIMPLIFY_MAP = str.maketrans({
-    '&': ' and ',
-    "'": None,
-    '\\': None,
-})
+SIMPLIFY_MAP = str.maketrans(
+    {
+        '&': ' and ',
+        "'": None,
+        '\\': None,
+    }
+)
 SIMPLIFY_MAP.update(dict.fromkeys([ord(ch) for ch in '_./-,[](){}:;!?@#%^*+<>=~`$'], ' '))
 
+
 class TextProcessingError(Exception):
     def __init__(self, value):
         super().__init__()
@@ -96,11 +109,11 @@ class LostFilm:
             'lf_session': {'type': 'string'},
             'prefilter': {'type': 'boolean'},
             'site_urls': {
-                'type': [ 'string', 'array'],
+                'type': ['string', 'array'],
                 'format': 'url',
                 'items': {'type': 'string', 'format': 'url'},
-            }
-         },
+            },
+        },
         'additionalProperties': False,
     }
 
@@ -138,8 +151,7 @@ class LostFilm:
         if config.get('lf_session') is not None:
             task.requests.cookies.set('lf_session', config['lf_session'])
             logger.debug('lf_session is set')
-        task.requests.headers.update({'Cache-Control': 'no-cache',
-                                      'Pragma': 'no-cache'})
+        task.requests.headers.update({'Cache-Control': 'no-cache', 'Pragma': 'no-cache'})
         prefilter_list = set()
         if config['prefilter']:
             prefilter_list = self._get_series(task)
@@ -156,17 +168,23 @@ class LostFilm:
         tried_urls = []
 
         while site_urls:
-            rss_url = site_urls[0] + "rss.xml" # If RSS url changes, update it here
+            rss_url = site_urls[0] + "rss.xml"  # If RSS url changes, update it here
             logger.trace('Trying to get and parse the RSS feed: {}', rss_url)
             try:
-                rss = feedparser.parse(rss_url, handlers=[proxy_handler],
-                          request_headers={'Cache-Control': 'no-cache',
-                                           'Pragma': 'no-cache'})
+                rss = feedparser.parse(
+                    rss_url,
+                    handlers=[proxy_handler],
+                    request_headers={'Cache-Control': 'no-cache', 'Pragma': 'no-cache'},
+                )
                 status = rss.get('status')
                 if status == 200:
                     logger.verbose('Received RSS feed from {}', rss_url)
                     break
-                logger.info('Received {} status instead of 200 (OK) when trying to download the RSS feed {}', status, rss_url)
+                logger.info(
+                    'Received {} status instead of 200 (OK) when trying to download the RSS feed {}',
+                    status,
+                    rss_url,
+                )
             except Exception as e:
                 logger.info('Cannot get or parse the RSS feed {}. Error: {}', rss_url, e)
             rss = None
@@ -218,22 +236,35 @@ class LostFilm:
                         folded_name = None
                     if folded_name and folded_name not in prefilter_list:
                         if idx != len(rss.entries) or entries or task.no_entries_ok:
-                            logger.debug('Skipping "{}" as "{}" was not found in the list of configured series',
-                                     item['title'], series_name_org)
+                            logger.debug(
+                                'Skipping "{}" as "{}" was not found in the list of configured series',
+                                item['title'],
+                                series_name_org,
+                            )
                             continue
                         else:
-                            logger.debug('Force adding the last RSS item to the result to avoid warning of empty output')
+                            logger.debug(
+                                'Force adding the last RSS item to the result to avoid warning of empty output'
+                            )
                     else:
-                        logger.trace('"{}" was found in the list of configured series', series_name_org)
+                        logger.trace(
+                            '"{}" was found in the list of configured series', series_name_org
+                        )
                 else:
-                    logger.debug('Not skipping RSS item as series names may be detected incorrectly')
+                    logger.debug(
+                        'Not skipping RSS item as series names may be detected incorrectly'
+                    )
 
             if item.get('description') is None:
                 logger.warning('RSS item doesn\'t have a description, skipping')
                 continue
             lostfilm_id_match = RSS_LF_ID_REGEXP.search(item['description'])
             if lostfilm_id_match is None or lostfilm_id_match['id'] is None:
-                logger.warning('RSS item doesn\'t have lostfilm id in the description: {}, skipping'. item['description'])
+                logger.warning(
+                    'RSS item doesn\'t have lostfilm id in the description: {}, skipping'.item[
+                        'description'
+                    ]
+                )
                 continue
             lostfilm_id = int(lostfilm_id_match['id'])
 
@@ -250,10 +281,19 @@ class LostFilm:
                 episode_num = int(link_match['episode'])
                 logger.verbose('Using imprecise information from RSS item \'link\'')
 
-            logger.trace(('Processing RSS entry: names: series "{}", series ru "{}", episode ru "{}"; '
-                          'numbers: season "{}", episode "{}", lostfilm id "{}"; perfect detect: {}'),
-                           series_name_org, series_name_rus, episode_name_rus,
-                           season_num, episode_num, lostfilm_id, perfect_match)
+            logger.trace(
+                (
+                    'Processing RSS entry: names: series "{}", series ru "{}", episode ru "{}"; '
+                    'numbers: season "{}", episode "{}", lostfilm id "{}"; perfect detect: {}'
+                ),
+                series_name_org,
+                series_name_rus,
+                episode_name_rus,
+                season_num,
+                episode_num,
+                lostfilm_id,
+                perfect_match,
+            )
             params = {'c': lostfilm_id, 's': season_num, 'e': episode_num}
 
             tried_urls = []
@@ -265,14 +305,28 @@ class LostFilm:
                     if response.status_code == 200:
                         logger.debug('The redirect page is downloaded from {}', redirect_url)
                         break
-                    logger.verbose('Got status {} while retriving the redirect page {}', response.status_code, redirect_url)
+                    logger.verbose(
+                        'Got status {} while retriving the redirect page {}',
+                        response.status_code,
+                        redirect_url,
+                    )
                 except RequestException as e:
-                    logger.verbose('Failed to get the redirect page from {}. Error: {}', redirect_url, e)
+                    logger.verbose(
+                        'Failed to get the redirect page from {}. Error: {}', redirect_url, e
+                    )
                 except cf_exceptions as e:
-                    logger.verbose('Cannot bypass CF page protection to get the redirect page {}. Error: {}', redirect_url, e)
+                    logger.verbose(
+                        'Cannot bypass CF page protection to get the redirect page {}. Error: {}',
+                        redirect_url,
+                        e,
+                    )
                 except Exception as e:
                     # Catch other errors related to download to avoid crash
-                    logger.warning('Got unexpected exception when trying to get the redirect page. Error: {}', redirect_url, e)
+                    logger.warning(
+                        'Got unexpected exception when trying to get the redirect page. Error: {}',
+                        redirect_url,
+                        e,
+                    )
                 response = None
                 tried_urls.append(site_urls.pop(0))
 
@@ -281,11 +335,15 @@ class LostFilm:
 
             if not response:
                 if config.get('lf_session') is not None:
-                    logger.error('Failed to get the redirect page. ' \
-                                 'Check whether "lf_session" parameter is correct.')
+                    logger.error(
+                        'Failed to get the redirect page. '
+                        'Check whether "lf_session" parameter is correct.'
+                    )
                 else:
-                    logger.error('Failed to get the redirect page. ' \
-                                 'Specify your "lf_session" cookie value in plugin parameters.')
+                    logger.error(
+                        'Failed to get the redirect page. '
+                        'Specify your "lf_session" cookie value in plugin parameters.'
+                    )
                 continue
 
             page = get_soup(response.content)
@@ -295,16 +353,26 @@ class LostFilm:
             if find_item is not None:
                 find_item = find_item.find('head', recursive=False)
                 if find_item is not None:
-                    find_item = find_item.find('meta', attrs={'http-equiv': "refresh"}, recursive=False)
-                    if find_item is not None and find_item.has_attr('content') and find_item['content'].startswith('0; url=http'):
+                    find_item = find_item.find(
+                        'meta', attrs={'http-equiv': "refresh"}, recursive=False
+                    )
+                    if (
+                        find_item is not None
+                        and find_item.has_attr('content')
+                        and find_item['content'].startswith('0; url=http')
+                    ):
                         download_page_url = find_item['content'][7:]
             if not download_page_url:
                 if config.get('lf_session') is not None:
-                    logger.error('Links were not foung on lostfilm.tv torrent download page. ' \
-                                 'Check whether "lf_session" parameter is correct.')
+                    logger.error(
+                        'Links were not foung on lostfilm.tv torrent download page. '
+                        'Check whether "lf_session" parameter is correct.'
+                    )
                 else:
-                    logger.error('Links were not foung on lostfilm.tv torrent download page. ' \
-                                 'Specify your "lf_session" cookie value in plugin parameters.')
+                    logger.error(
+                        'Links were not foung on lostfilm.tv torrent download page. '
+                        'Specify your "lf_session" cookie value in plugin parameters.'
+                    )
                 continue
 
             try:
@@ -313,11 +381,19 @@ class LostFilm:
                 logger.error('Failed to get the download page {}. Error: {}', download_page_url, e)
                 continue
             except cf_exceptions as e:
-                logger.error('Cannot pass CF page protection to get the download page {}. Error: {}', download_page_url, e)
+                logger.error(
+                    'Cannot pass CF page protection to get the download page {}. Error: {}',
+                    download_page_url,
+                    e,
+                )
                 continue
             except Exception as e:
                 # Catch other errors related to download to avoid crash
-                logger.error('Got unexpected exception when trying to get the download page {}. Error: {}', download_page_url, e)
+                logger.error(
+                    'Got unexpected exception when trying to get the download page {}. Error: {}',
+                    download_page_url,
+                    e,
+                )
                 continue
 
             page = get_soup(response.content)
@@ -330,13 +406,14 @@ class LostFilm:
                     if title_org_div.endswith(', сериал') and len(title_org_div) != 8:
                         series_name_org = title_org_div[:-8]
                     else:
-                        logger.info('Cannot parse text on the final download page for original series name')
+                        logger.info(
+                            'Cannot parse text on the final download page for original series name'
+                        )
                 else:
                     logger.info('Cannot parse the final download page for original series name')
 
                 find_item = page.find('div', class_='inner-box--title')
-                if find_item is not None and \
-                   find_item.text.strip():
+                if find_item is not None and find_item.text.strip():
                     series_name_rus = find_item.text.strip()
                 else:
                     logger.info('Cannot parse the final download page for russian series name')
@@ -345,16 +422,29 @@ class LostFilm:
             if find_item is not None:
                 info_match = PAGE_TEXT_REGEXP.fullmatch(find_item.text.strip())
                 if info_match is not None:
-                    if int(info_match['season']) != season_num or int(info_match['episode']) != episode_num:
-                        logger.warning(('Using season number ({}) and episode number ({}) from download page instead of '
-                                    'season number ({}) and episode number ({}) in RSS item'), int(info_match['season']),
-                                    int(info_match['episode']), season_num, episode_num)
+                    if (
+                        int(info_match['season']) != season_num
+                        or int(info_match['episode']) != episode_num
+                    ):
+                        logger.warning(
+                            (
+                                'Using season number ({}) and episode number ({}) from download page instead of '
+                                'season number ({}) and episode number ({}) in RSS item'
+                            ),
+                            int(info_match['season']),
+                            int(info_match['episode']),
+                            season_num,
+                            episode_num,
+                        )
                         season_num = int(info_match['season'])
                         eposode_num = int(info_match['episode'])
                     if info_match['ep_org'] is not None:
                         episode_name_org = info_match['ep_org'].strip()
-                    if not perfect_match and info_match['ep_rus'] is not None and \
-                      info_match['ep_rus'].strip():
+                    if (
+                        not perfect_match
+                        and info_match['ep_rus'] is not None
+                        and info_match['ep_rus'].strip()
+                    ):
                         episode_name_rus = info_match['ep_rus'].strip()
                 else:
                     logger.info('Cannot parse text on the final download page for episode names')
@@ -374,9 +464,13 @@ class LostFilm:
             if not series_name_org:
                 find_item = item.get['title']
                 if find_item:
-                    logger.warning(('Unable to detect series name. Full RSS item title will be used in hope '
-                                    'that series parser will be able to detect something: {}'),
-                                    find_item)
+                    logger.warning(
+                        (
+                            'Unable to detect series name. Full RSS item title will be used in hope '
+                            'that series parser will be able to detect something: {}'
+                        ),
+                        find_item,
+                    )
                     series_name_org = None
                 else:
                     logger.error('Unable to detect series name. Skipping RSS item.')
@@ -408,13 +502,7 @@ class LostFilm:
                     quality = lf_quality
                 if series_name_org:
                     new_title = '.'.join(
-                        [
-                            series_name_org,
-                            episode_id,
-                            quality,
-                            r_type,
-                            'LostFilm.TV'
-                        ]
+                        [series_name_org, episode_id, quality, r_type, 'LostFilm.TV']
                     )
                 else:
                     new_title = '{} {}'.format(item['title'], quality).strip()
@@ -449,14 +537,24 @@ class LostFilm:
                     new_entry['episode_name_org'] = episode_name_org
                 new_entry['lostfilm_id'] = lostfilm_id
                 entries.append(new_entry)
-                logger.trace(('Added new entry: names: series "{}", series ru "{}", episode "{}", episode ru "{}"; '
-                        'numbers: season "{}", episode "{}", lostfilm id "{}"; quality: "{}", perfect detect: {}'),
-                        series_name_org, series_name_rus, episode_name_org, episode_name_rus,
-                        season_num, episode_num, lostfilm_id, quality, perfect_match)
+                logger.trace(
+                    (
+                        'Added new entry: names: series "{}", series ru "{}", episode "{}", episode ru "{}"; '
+                        'numbers: season "{}", episode "{}", lostfilm id "{}"; quality: "{}", perfect detect: {}'
+                    ),
+                    series_name_org,
+                    series_name_rus,
+                    episode_name_org,
+                    episode_name_rus,
+                    season_num,
+                    episode_num,
+                    lostfilm_id,
+                    quality,
+                    perfect_match,
+                )
 
         return entries
 
-
     @staticmethod
     def _simplify_name(name: str) -> str:
         name = normalize_unicode(name)
@@ -466,7 +564,6 @@ class LostFilm:
             raise TextProcessingError('Simplified name of series is empty')
         return name
 
-
     @staticmethod
     def _get_series(task):
         if not task.config.get('series'):
@@ -494,7 +591,6 @@ class LostFilm:
 
         return names_list
 
-
     @staticmethod
     def _add_names_from_cfg_list(names_list: set, cfg_list: list) -> None:
         for s_item in cfg_list:
@@ -514,10 +610,13 @@ class LostFilm:
                         for a_name in s_cfg['alternate_name']:
                             names_list.add(LostFilm._simplify_name(a_name))
                     else:
-                        raise PluginError('Cannot read series "alternate_name" for "{:s}"'.format(s_name))
+                        raise PluginError(
+                            'Cannot read series "alternate_name" for "{:s}"'.format(s_name)
+                        )
             else:
-                raise PluginError('Series configuration list item has ' \
-                                  'unsupported type: %s' % type(s_item))
+                raise PluginError(
+                    'Series configuration list item has ' 'unsupported type: %s' % type(s_item)
+                )
 
 
 @event('plugin.register')
