@@ -8,6 +8,7 @@ from flexget.config_schema import one_or_more
 from flexget.event import event
 from flexget.utils import json
 from flexget.utils.template import RenderError
+
 logger = logger.bind(name='pyload')
 
 
@@ -122,15 +123,6 @@ class PluginPyLoad:
 
         self.add_entries(task, config)
 
-    @staticmethod
-    def get_version_from_packaging():
-        version = None
-        try:
-            from packaging import version
-        except ModuleNotFoundError:
-            logger.warning('packaging is not installed')
-        return version
-
     def add_entries(self, task, config):
         """Adds accepted entries"""
 
@@ -146,26 +138,18 @@ class PluginPyLoad:
         except Exception as e:
             raise plugin.PluginError('Unknown error: %s' % str(e), logger)
 
-        remote_version = None
-        try:
-            remote_version = api.get('getServerVersion')
-        except RequestException as e:
-            if e.response is not None and e.response.status_code == 404:
-                remote_version = json.loads(api.get('get_server_version').content)
-            else:
-                raise e
-
+        # old pyload (stable)
+        is_pyload_ng = False
         parse_urls_command = 'parseURLs'
         add_package_command = 'addPackage'
         set_package_data_command = 'setPackageData'
 
-        is_pyload_ng = False
-        version = self.get_version_from_packaging()
-        if version and version.parse(remote_version) >= version.parse('0.5'):
+        # pyload-ng is returning dict instead of session string on login
+        if isinstance(session, dict):
+            is_pyload_ng = True
             parse_urls_command = 'parse_urls'
             add_package_command = 'add_package'
             set_package_data_command = 'set_package_date'
-            is_pyload_ng = True
 
         hoster = config.get('hoster', self.DEFAULT_HOSTER)
 
@@ -175,11 +159,7 @@ class PluginPyLoad:
             content = json.dumps(content)
 
             if is_pyload_ng:
-                url = (
-                    entry['url']
-                    if config.get('parse_url', self.DEFAULT_PARSE_URL)
-                    else ''
-                )
+                url = entry['url'] if config.get('parse_url', self.DEFAULT_PARSE_URL) else ''
             else:
                 url = (
                     json.dumps(entry['url'])
@@ -196,7 +176,7 @@ class PluginPyLoad:
 
             parsed = result.json()
 
-            urls = []
+            urls = entry.get('urls', [])
 
             # check for preferred hoster
             for name in hoster:
@@ -251,7 +231,7 @@ class PluginPyLoad:
                         'name': json.dumps(name.encode('ascii', 'ignore').decode()),
                         'links': json.dumps(urls),
                         'dest': json.dumps(dest),
-                        'session': session
+                        'session': session,
                     }
 
                 pid = api.post(add_package_command, data=data).text
