@@ -1,18 +1,16 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
-import logging
-import re
 import os
+import re
+
+from loguru import logger
 
 from flexget import plugin
 from flexget.event import event
 
-log = logging.getLogger('rtorrent_magnet')
+logger = logger.bind(name='rtorrent_magnet')
 pat = re.compile('xt=urn:btih:([^&/]+)')
 
 
-class PluginRtorrentMagnet(object):
+class PluginRtorrentMagnet:
     """
     Process Magnet URI's into rtorrent compatible torrent files
 
@@ -39,9 +37,9 @@ class PluginRtorrentMagnet(object):
         path = os.path.expanduser(path)
 
         if task.options.test:
-            log.info('Would write: %s' % path)
+            logger.info('Would write: {}', path)
         else:
-            log.info('Writing rTorrent Magnet File: %s', path)
+            logger.info('Writing rTorrent Magnet File: {}', path)
             with open(path, 'w') as f:
                 f.write('d10:magnet-uri%d:%se' % (len(entry['url']), entry['url']))
         entry['output'] = path
@@ -52,17 +50,19 @@ class PluginRtorrentMagnet(object):
 
         for entry in task.accepted:
             if 'output' in entry:
-                log.debug('Ignoring, %s already has an output file: %s' % (entry['title'], entry['output']))
+                logger.debug(
+                    'Ignoring, {} already has an output file: {}', entry['title'], entry['output']
+                )
                 continue
 
             for url in entry.get('urls', [entry['url']]):
                 if url.startswith('magnet:'):
-                    log.debug('Magnet URI detected for url %s (%s)' % (url, entry['title']))
+                    logger.debug('Magnet URI detected for url {} ({})', url, entry['title'])
                     if pat.search(url):
                         self.write_torrent_file(task, entry, entry.get('path', config))
                         break
                     else:
-                        log.warning('Unrecognized Magnet URI Format: %s', url)
+                        logger.warning('Unrecognized Magnet URI Format: {}', url)
 
 
 @event('plugin.register')
