@@ -1,6 +1,3 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
 import json
 
 import pytest
@@ -9,16 +6,21 @@ from flexget.api.app import base_message
 from flexget.api.core.database import ObjectsContainer as OC
 
 
-class TestDatabaseAPI(object):
+class TestDatabaseAPI:
     config = 'tasks: {}'
 
-    @pytest.mark.parametrize('operation, plugin_name, status, schema', [
-        ('cleanup', None, 200, base_message),
-        ('vacuum', None, 200, base_message),
-        ('plugin_reset', 'bla', 400, base_message),
-        ('plugin_reset', 'tvmaze', 200, base_message),
-    ])
-    def test_database_methods(self, operation, plugin_name, status, schema, api_client, schema_match):
+    @pytest.mark.parametrize(
+        'operation, plugin_name, status, schema',
+        [
+            ('cleanup', None, 200, base_message),
+            ('vacuum', None, 200, base_message),
+            ('plugin_reset', 'bla', 400, base_message),
+            ('plugin_reset', 'tvmaze', 200, base_message),
+        ],
+    )
+    def test_database_methods(
+        self, operation, plugin_name, status, schema, api_client, schema_match
+    ):
         payload = {'operation': operation}
         if plugin_name:
             payload['plugin_name'] = plugin_name
