@@ -1,14 +1,11 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
 import pytest
 
-from flexget.api.plugins.imdb_lookup import ObjectsContainer as OC
+from flexget.components.imdb.api import ObjectsContainer as OC
 from flexget.utils import json
 
 
 @pytest.mark.online
-class TestIMDBLookupAPI(object):
+class TestIMDBLookupAPI:
     config = 'tasks: {}'
 
     def test_imdb_search(self, api_client, schema_match):
@@ -17,7 +14,7 @@ class TestIMDBLookupAPI(object):
         assert rsp.status_code == 404, 'Response code is %s' % rsp.status_code
 
         # Lookup by title
-        rsp = api_client.get('/imdb/search/matrix/')
+        rsp = api_client.get('/imdb/search/saw/')
         assert rsp.status_code == 200, 'Response code is %s' % rsp.status_code
 
         data = json.loads(rsp.get_data(as_text=True))
