@@ -6,6 +6,7 @@ from contextlib import suppress
 from copy import copy
 from datetime import date, datetime, time
 from typing import TYPE_CHECKING, Any, AnyStr, List, Mapping, Optional, Type, Union, cast
+from unicodedata import normalize
 
 import jinja2.filters
 from dateutil import parser as dateutil_parse
@@ -142,6 +143,35 @@ def filter_default(value, default_value: str = '', boolean: bool = True) -> str:
 filter_d = filter_default
 
 
+def filter_asciify(text: str) -> str:
+    """Siplify text"""
+
+    if not isinstance(text, str):
+        return text
+
+    result = normalize('NFD', text)
+    result = result.encode('ascii', 'ignore')
+    result = result.decode("utf-8")
+    result = str(result)
+    return result
+
+
+def filter_strip_symbols(text: str) -> str:
+    """Strip Symbols text"""
+
+    if not isinstance(text, str):
+        return text
+
+    # Symbols that should be converted to white space
+    result = re.sub(r'[ \(\)\-_\[\]\.]+', ' ', text)
+    # Leftovers
+    result = re.sub(r"[^\w\d\s]", "", result, flags=re.UNICODE)
+    # Replace multiple white spaces with one
+    result = ' '.join(result.split())
+
+    return result
+
+
 def filter_strip_year(name: str) -> str:
     return split_title_year(name).title
 
